# vokab

vokab is a python module for storing, searching and matching named entities on their name or aliases. This 
project is useful for auto-correcting or linking named entities in NLP information extraction use cases or 
when cleaning up user submitted data.

Supports:
- Exact Matching
- Case-insensitive Matching
- Lexical Matching (i.e. Fuzzy String Matching)
- Semantic Matching (i.e. Vector Similarity Searching)
- Hybrid (Lexical/Fuzzy + Semantic/Vector)


## Getting Started


## Installation

Available on [PyPI](https://pypi.org/project/vokab/):

```bash
pip install vokab
```


## Maintainer

vokab was created by [Ian Maurer](https://x.com/imaurer), the CTO of [GenomOncology](https://genomoncology.com).

This MIT-based open-source project was extracted from our product which includes the ability to normalize biomedical
data for use in precision oncology clinical decision support systems. Contact me to learn more about our product
offerings.


